@@ -4,7 +4,7 @@ use FindBin;
 use Test::ModuleVersion;
 
 my $tm = Test::ModuleVersion->new;
-$tm->exclude([qw/TimeDate Perl Mail/]);
+$tm->exclude([qw/TimeDate Mail/]);
 $tm->show_lack_module_url(1);
 open my $fh, '>', "$FindBin::Bin/module.t"
   or die $!;
